AtomicRawBufferVec

Struct AtomicRawBufferVec 

pub struct AtomicRawBufferVec<T>
where T: AtomicPod,
{ /* private fields */ }
A RawBufferVec that holds data that implements AtomicPod.

This allows multiple threads to update the buffer to be sent to the GPU simultaneously. Note that they may only update existing data; pushing new data still requires exclusive access.

Implementations

Source

impl<T> AtomicRawBufferVec<T>
where T: AtomicPod,

pub const fn new(buffer_usage: BufferUsages) -> Self

Creates a new AtomicRawBufferVec.

The buffer_usage parameter tells wgpu which usages are allowed for the backing buffer.

pub fn with_label(buffer_usage: BufferUsages, label: &str) -> Self

Creates a new AtomicRawBufferVec with a custom label.

The buffer_usage parameter tells wgpu which usages are allowed for the backing buffer.

pub fn clear(&mut self)

Removes all elements from the buffer.

pub fn len(&self) -> u32

Returns the number of elements in the buffer.

pub fn is_empty(&self) -> bool

Returns true if the vector is empty.

pub fn push(&mut self, value: T) -> u32

Adds a new value to the buffer, and returns its index.

Internally, the value is converted to its blob representation.

pub fn get(&self, index: u32) -> T

Copies a value out of the buffer.

pub fn set(&self, index: u32, value: T)

Sets the value at the given index.

If the index isn’t in range of the buffer, this method panics.

Internally, the value is converted to its blob representation.

Note that this method is thread-safe and doesn’t require &mut self. It’s your responsibility, however, to ensure synchronization; though this method is memory-safe, it’s possible for other threads to observe partially-overwritten values if Self::get or similar methods are called while the write operation is occurring.

pub fn reserve(&mut self, capacity: usize, device: &RenderDevice)

Creates a Buffer on the RenderDevice with size at least size_of::<T>() * capacity, unless a such a buffer already exists.

If a Buffer exists, but is too small, references to it will be discarded, and a new Buffer will be created. Any previously created Buffers that are no longer referenced will be deleted by the RenderDevice once it is done using them (typically 1-2 frames).

In addition to any BufferUsages provided when the AtomicRawBufferVec was created, the buffer on the RenderDevice is marked as BufferUsages::COPY_DST.

pub fn write_buffer(&mut self, device: &RenderDevice, queue: &RenderQueue)

Queues writing of data from system RAM to VRAM using the RenderDevice and the provided RenderQueue.

Before queuing the write, a reserve operation is executed.

pub fn write_buffer_range( &mut self, range: Range<usize>, device: &RenderDevice, queue: &RenderQueue, )

Queues writing of data from system RAM to VRAM using the RenderDevice and the provided RenderQueue.

Before queuing the write, a reserve operation is executed.

pub fn buffer(&self) -> Option<&Buffer>

Returns a handle to the buffer, if the data has been uploaded.

pub fn grow(&mut self, new_len: u32)

Grows the buffer by adding default values so that it’s at least the given size.

If the buffer is already large enough, this method does nothing.

pub fn truncate(&mut self, len: u32)

Truncates the buffer to the given length.

If the buffer is already shorter, this method does nothing.