pub struct DefaultImageSampler(/* private fields */);Expand description
A rendering resource for the default image sampler which is set during renderer initialization.
The ImagePlugin can be set during app initialization to change the default
image sampler.