#[repr(C)]pub struct Extent3d {
pub width: u32,
pub height: u32,
pub depth_or_array_layers: u32,
}Expand description
Extent of a texture related operation.
Corresponds to WebGPU GPUExtent3D.
Fields
width: u32Width of the extent
height: u32Height of the extent
depth_or_array_layers: u32The depth of the extent or the number of array layers
Implementations
Sourceimpl Extent3d
impl Extent3d
Sourcepub fn physical_size(&self, format: TextureFormat) -> Extent3d
pub fn physical_size(&self, format: TextureFormat) -> Extent3d
Calculates the physical size backing a texture of the given format and extent. This includes padding to the block width and height of the format.
This is the texture extent that you must upload at when uploading to mipmaps of compressed textures.
Sourcepub fn max_mips(&self, dim: TextureDimension) -> u32
pub fn max_mips(&self, dim: TextureDimension) -> u32
Calculates the maximum possible count of mipmaps.
Treats the depth as part of the mipmaps. If calculating for a 2DArray texture, which does not mipmap depth, set depth to 1.