PartialBufferVec

Struct PartialBufferVec 

pub struct PartialBufferVec<T>
where T: NoUninit,
{ /* private fields */ }
A hybrid of RawBufferVec and UninitBufferVec that allows the CPU to push elements and to leave room for uninitialized elements for the GPU to populate at the end of the array.

All CPU elements mush be pushed before any trailing uninitialized elements can be reserved. In debug mode, this data structure enforces these preconditions with assertions.

Implementations

Source

impl<T> PartialBufferVec<T>
where T: NoUninit,

pub fn new(buffer_usages: BufferUsages, label: String) -> PartialBufferVec<T>

Creates a new PartialBufferVec with the given allowed usages and the given debugging label.

BufferUsages::COPY_DST is implicitly added to the supplied set of usages.

pub fn buffer(&self) -> Option<&Buffer>

Returns the allocated GPU buffer, if one exists.

pub fn clear(&mut self)

Clears out the buffer, setting both the number of CPU-initialized elements and extra uninitialized trailing elements to 0.

pub fn write_buffer( &mut self, render_device: &RenderDevice, render_queue: &RenderQueue, )

Writes the buffer to the GPU.

Self::reserve is called automatically to ensure that the buffer has the correct length (including enough space to hold all the trailing uninitialized elements).

pub fn is_empty(&self) -> bool

Returns true if this buffer is empty: i.e. if Self::len would return 0.

pub fn len(&self) -> usize

Returns the total number of elements, both initialized and uninitialized, in this buffer.

That is, this method returns the sum of the number of initialized values that the CPU pushed and the number of trailing uninitialized elements that have been allocated.

pub fn push_init(&mut self, value: T) -> usize

Pushes an element with the given value to the buffer and returns its index.

Since this element is initialized by the CPU, and all CPU-initialized elements must precede any trailing uninitialized elements, this method panics in debug mode if Self::push_multiple_uninit has been called since the last call to Self::clear.

pub fn push_multiple_uninit(&mut self, count: usize) -> usize

Pushes the given number of uninitialized elements to the end of the list and returns the index of the first such element that was pushed.

After calling this method with a nonzero count, it’s no longer legal to call Self::push_init without calling Self::clear first.