SparseBufferHandle

Type Alias SparseBufferHandle 

pub type SparseBufferHandle = Arc<SparseBufferId>;
An object that allows the sparse buffer ID to be query and holds the bind group for that sparse buffer alive.

Each sparse buffer holds a strong reference to this handle, and the SparseBufferUpdateBindGroups resource contains a weak map from this handle to the bind group. This setup ensures that, when the sparse buffer is freed, the bind groups for that sparse buffer are freed as well.

Aliased Type

pub struct SparseBufferHandle { /* private fields */ }