pub struct AtomicRawBufferVec<T>where
T: AtomicPod,{ /* private fields */ }Expand description
A RawBufferVec that holds data that implements AtomicPod.
This allows multiple threads to update the buffer to be sent to the GPU simultaneously. Note that they may only update existing data; pushing new data still requires exclusive access.
Implementations
Sourceimpl<T> AtomicRawBufferVec<T>where
T: AtomicPod,
impl<T> AtomicRawBufferVec<T>where
T: AtomicPod,
Sourcepub const fn new(buffer_usage: BufferUsages) -> Self
pub const fn new(buffer_usage: BufferUsages) -> Self
Creates a new AtomicRawBufferVec.
The buffer_usage parameter tells wgpu which usages are allowed for
the backing buffer.
Sourcepub fn with_label(buffer_usage: BufferUsages, label: &str) -> Self
pub fn with_label(buffer_usage: BufferUsages, label: &str) -> Self
Creates a new AtomicRawBufferVec with a custom label.
The buffer_usage parameter tells wgpu which usages are allowed for
the backing buffer.
Sourcepub fn push(&mut self, value: T) -> u32
pub fn push(&mut self, value: T) -> u32
Adds a new value to the buffer, and returns its index.
Internally, the value is converted to its blob representation.
Sourcepub fn set(&self, index: u32, value: T)
pub fn set(&self, index: u32, value: T)
Sets the value at the given index.
If the index isn’t in range of the buffer, this method panics.
Internally, the value is converted to its blob representation.
Note that this method is thread-safe and doesn’t require &mut self.
It’s your responsibility, however, to ensure synchronization; though
this method is memory-safe, it’s possible for other threads to observe
partially-overwritten values if Self::get or similar methods are
called while the write operation is occurring.
Sourcepub fn reserve(&mut self, capacity: usize, device: &RenderDevice)
pub fn reserve(&mut self, capacity: usize, device: &RenderDevice)
Creates a Buffer on the RenderDevice with size
at least size_of::<T>() * capacity, unless a such a buffer already exists.
If a Buffer exists, but is too small, references to it will be discarded,
and a new Buffer will be created. Any previously created Buffers
that are no longer referenced will be deleted by the RenderDevice
once it is done using them (typically 1-2 frames).
In addition to any BufferUsages provided when
the AtomicRawBufferVec was created, the buffer on the RenderDevice
is marked as BufferUsages::COPY_DST.
Sourcepub fn write_buffer(&mut self, device: &RenderDevice, queue: &RenderQueue)
pub fn write_buffer(&mut self, device: &RenderDevice, queue: &RenderQueue)
Queues writing of data from system RAM to VRAM using the
RenderDevice and the provided RenderQueue.
Before queuing the write, a reserve
operation is executed.
Sourcepub fn write_buffer_range(
&mut self,
range: Range<usize>,
device: &RenderDevice,
queue: &RenderQueue,
)
pub fn write_buffer_range( &mut self, range: Range<usize>, device: &RenderDevice, queue: &RenderQueue, )
Queues writing of data from system RAM to VRAM using the
RenderDevice and the provided RenderQueue.
Before queuing the write, a reserve
operation is executed.
Sourcepub fn buffer(&self) -> Option<&Buffer>
pub fn buffer(&self) -> Option<&Buffer>
Returns a handle to the buffer, if the data has been uploaded.